
// This file serves as a Initialization Code to change the PLL/SSEL/CSEL to expedite Booting Process

#include <defBF533.h>

// Added by JW
#define PLL_msel	14     
#define PLL_d		0x0     
#define PLL_count	0x200
#define PLL_bypass	0x0
#define PLL_csel	0     
#define PLL_ssel	13    

#define ASYNC_SETUP		2
#define ASYNC_ACCESS	3
#define ASYNC_HOLD		1

#define SPI_setting 12

.section program;


start:
/********************************************************************/
[--SP] = ASTAT; // Save registers onto Stack
[--SP] = RETS;
[--SP] = (R7:0);
[--SP] = (P5:0);
/********************************************************************/
/*******Init Code Section********************************************/

// Tune to the new/initialization PLL setting
	p0.l = lo(PLL_LOCKCNT);
	p0.h = hi(PLL_LOCKCNT);		
	r0.l = PLL_count;
	r0.h = 0;
	w[p0] = r0;	
	
	// For PLL_CTL
	p0.l = lo(PLL_CTL);
	p0.h = hi(PLL_CTL);
	r1 = w[p0](z);
	r0 = 0(z);
		
	// PLL_D
	bitclr(r1,0);
	r0.l = PLL_d & 0x1;
	r1 = r1 | r0;
	
	// PLL_MSEL
	r0.l = ~(0x3f << 9);
	r1 = r1 & r0;
	r0.l = PLL_msel << 9;
	r1 = r1 | r0;	
	
	// For PLL_DIV
	p2.l = lo(PLL_DIV);
	p2.h = hi(PLL_DIV);	
	r2.l = PLL_ssel;
	r0.l = PLL_csel << 4;
	r2 = r2|r0;	
	
	// For Flash Bank0
	p3.l = lo(EBIU_AMBCTL0);
	p3.h = hi(EBIU_AMBCTL0);
	r3 = w[p3](z);
	r4 = 0xf;
	r3 = r3 & r4;
	
	r0 = ASYNC_SETUP << 4;
	r4=(ASYNC_HOLD << 6 );
	r0 = r0 | r4;
	r4=(ASYNC_ACCESS << 8 );
	r0 = r0 | r4;
	r4=(ASYNC_ACCESS << 12 );
	r0 = r0 | r4;
	
	r3 = r3 | r0;
	
	p4.h = hi( SPI_BAUD );
	p4.l = lo( SPI_BAUD );
	r4 = SPI_setting;
	
	
 	p1.l = lo(SIC_IWR);  // enable PLL Wakeup Interrupt
	p1.h = hi(SIC_IWR);
	r0 = [p1];			
	bitset(r0,0);	  
	[p1] = r0;
	
 	w[p4] = r4;			// apply SPI setting
	w[p3] = r3;			// apply FLASH setting
	w[p2] = r2;			// apply PLL_DIV setting
	w[p0] = r1;         // Apply PLL_CTL changes.
	ssync;
 	
	cli r2; // disable interrupts 15-5
 	idle;	// wait for Loop_count expired wake up
 	sti r2; // enable interrupts 15-5
 //end of Tuned to start setting

 
/********************************************************************/
(P5:0) = [SP++]; // Restore registers from Stack
(R7:0) = [SP++];
RETS = [SP++];
ASTAT = [SP++];
/********************************************************************/
RTS;

start.end: nop;	




